"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var TicketCollection_1 = require("../Ticket/TicketCollection");
var TimeSessionCollection_1 = require("../TimeSession/TimeSessionCollection");
var CategoryCollection_1 = require("../Ticket/Category/CategoryCollection");
var PriorityCollection_1 = require("../Ticket/Priority/PriorityCollection");
var StatusCollection_1 = require("../Ticket/Status/StatusCollection");
var TypeCollection_1 = require("../Ticket/Type/TypeCollection");
var js2xmlparser = require("js2xmlparser");
var decamelizeKeys = require('decamelize-keys');
var Project = /** @class */ (function () {
    function Project(id, name, status, permalink, totalTicketCount, openTicketCount, closedTicketCount) {
        this.id = id;
        this.name = name;
        this.status = status;
        this.permalink = permalink;
        this.totalTicketCount = totalTicketCount;
        this.openTicketCount = openTicketCount;
        this.closedTicketCount = closedTicketCount;
        this.ticketCollection = new TicketCollection_1.default();
        this.timeSessionCollection = new TimeSessionCollection_1.default();
        this.ticketCategoryCollection = new CategoryCollection_1.default();
        this.ticketPriorityCollection = new PriorityCollection_1.default();
        this.ticketStatusCollection = new StatusCollection_1.default();
        this.ticketTypeCollection = new TypeCollection_1.default();
    }
    Project.prototype.convertToXml = function () {
        var project = JSON.stringify(this);
        var projectString = JSON.parse(project);
        delete this.ticketCollection;
        delete this.timeSessionCollection;
        delete this.ticketCategoryCollection;
        delete this.ticketPriorityCollection;
        delete this.ticketStatusCollection;
        delete this.ticketTypeCollection;
        projectString = decamelizeKeys(projectString, '-');
        return js2xmlparser.parse("project", projectString);
    };
    /**
     * Gets project id
     * @return number
     */
    Project.prototype.getId = function () {
        return this.id;
    };
    /**
     * Gets project name
     * @return string
     */
    Project.prototype.getName = function () {
        return this.name;
    };
    Project.prototype.getStatus = function () {
        return this.status;
    };
    Project.prototype.getPermalink = function () {
        return this.permalink;
    };
    Project.prototype.getTotalTicketCount = function () {
        return this.totalTicketCount;
    };
    Project.prototype.getOpenTicketCount = function () {
        return this.openTicketCount;
    };
    Project.prototype.getClosedTicketCount = function () {
        return this.closedTicketCount;
    };
    Project.prototype.getTickets = function () {
        return this.ticketCollection;
    };
    Project.prototype.addTicket = function (ticket) {
        this.ticketCollection.addTicket(ticket);
        return this;
    };
    Project.prototype.getTimeSessions = function () {
        return this.timeSessionCollection;
    };
    Project.prototype.addTimeSession = function (timeSession) {
        this.timeSessionCollection.addTimeSession(timeSession);
        return this;
    };
    Project.prototype.getTicketCategories = function () {
        return this.ticketCategoryCollection;
    };
    Project.prototype.getTicketCategoryById = function (id) {
        return this.ticketCategoryCollection.searchById(id);
    };
    Project.prototype.addTicketCategory = function (ticketCategory) {
        this.ticketCategoryCollection.addTicketCategory(ticketCategory);
        return this;
    };
    Project.prototype.getTicketPriorities = function () {
        return this.ticketPriorityCollection;
    };
    Project.prototype.getTicketPriorityById = function (id) {
        return this.ticketPriorityCollection.searchById(id);
    };
    Project.prototype.addTicketPriority = function (ticketPriority) {
        this.ticketPriorityCollection.addTicketPriority(ticketPriority);
        return this;
    };
    Project.prototype.getTicketStatuses = function () {
        return this.ticketStatusCollection;
    };
    Project.prototype.getTicketStatusById = function (id) {
        return this.ticketStatusCollection.searchById(id);
    };
    Project.prototype.addTicketStatus = function (ticketStatus) {
        this.ticketStatusCollection.addTicketStatus(ticketStatus);
    };
    Project.prototype.getTicketTypes = function () {
        return this.ticketTypeCollection;
    };
    Project.prototype.getTicketTypeById = function (id) {
        return this.ticketTypeCollection.searchById(id);
    };
    Project.prototype.addTicketType = function (ticketType) {
        return this.ticketTypeCollection.addTicketType(ticketType);
    };
    return Project;
}());
exports.default = Project;
