import Category from "./Category/Category";
import Priority from "./Priority/Priority";
import Status from "./Status/Status";
import Type from "./Type/Type";
import TimeSessionCollection from "../TimeSession/TimeSessionCollection";
import TimeSession from "../TimeSession/TimeSession";
import User from "../User/User";
import BaseModelInterface from "../BaseModelInterface";
export default class Ticket implements BaseModelInterface {
    private id;
    private projectId;
    private summary;
    private updatedAt;
    private createdAt;
    private totalTimeSpent;
    private reporter;
    private assignee;
    private category;
    private priority;
    private status;
    private type;
    private estimatedTime;
    private timeSessionCollection;
    constructor(id: number, projectId: number, summary: string, updatedAt: Date, createdAt: Date, totalTimeSpent: number, reporter?: User | null, assignee?: User | null, category?: Category | null, priority?: Priority | null, status?: Status | null, type?: Type | null, estimatedTime?: number | null);
    convertToXml(): any;
    /**
     * Gets Ticket id
     * @return number
     */
    getId(): number;
    /**
     * Gets Ticket Project ID
     * @return number
     */
    getProjectId(): number;
    /**
     * Gets Ticket summary
     * @return string
     */
    getSummary(): string;
    /**
     * Gets Ticket Reporter
     * @return null|User
     */
    getReporter(): User | null;
    /**
     * Gets Ticket Assignee
     * @return null|User
     */
    getAssignee(): User | null;
    /**
     * Gets Ticket category
     * @return null|Category
     */
    getCategory(): Category | null;
    /**
     * Gets Ticket priority
     * @return null|Priority\Priority
     */
    getPriority(): Priority | null;
    /**
     * Gets Ticket status
     * @return null|Status\Status
     */
    getStatus(): Status | null;
    /**
     * Gets Ticket type
     * @return null|Type\Type
     */
    getType(): Type | null;
    /**
     * Gets Ticket estimated time
     * @return null|int
     */
    getEstimate(): number | null;
    /**
     * Gets Ticket total time spent
     * @return int
     */
    getTotalTimeSpent(): number;
    /**
     * Gets Ticket updated date
     * @return \DateTime
     */
    getUpdatedAt(): Date;
    /**
     * Gets Ticket created date
     * @return \DateTime
     */
    getCreatedAt(): Date;
    /**
     * Returns time session collection
     * @return TimeSession\Collection
     */
    getTimeSessions(): TimeSessionCollection;
    addTimeSession(timeSession: TimeSession): this;
}
