"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var TimeSessionCollection_1 = require("../TimeSession/TimeSessionCollection");
var js2xmlparser = require("js2xmlparser");
var decamelizeKeys = require('decamelize-keys');
var Ticket = /** @class */ (function () {
    function Ticket(id, projectId, summary, updatedAt, createdAt, totalTimeSpent, reporter, assignee, category, priority, status, type, estimatedTime) {
        if (reporter === void 0) { reporter = null; }
        if (assignee === void 0) { assignee = null; }
        if (category === void 0) { category = null; }
        if (priority === void 0) { priority = null; }
        if (status === void 0) { status = null; }
        if (type === void 0) { type = null; }
        if (estimatedTime === void 0) { estimatedTime = null; }
        this.id = id;
        this.projectId = projectId;
        this.summary = summary;
        this.reporter = reporter;
        this.assignee = assignee;
        this.category = category;
        this.priority = priority;
        this.status = status;
        this.type = type;
        this.estimatedTime = estimatedTime;
        this.updatedAt = updatedAt;
        this.createdAt = createdAt;
        this.totalTimeSpent = totalTimeSpent;
        this.timeSessionCollection = new TimeSessionCollection_1.default();
    }
    Ticket.prototype.convertToXml = function () {
        var ticket = JSON.stringify(this);
        var ticketString = JSON.parse(ticket);
        if (this.reporter) {
            ticketString.reporterId = this.reporter.getId();
            ticketString.reporter = this.reporter.getFullName();
        }
        if (this.assignee) {
            ticketString.assigneeId = this.assignee.getId();
            ticketString.assignee = this.assignee.getFullName();
        }
        if (this.category) {
            ticketString.categoryId = this.category.getId();
        }
        if (this.priority) {
            ticketString.priorityId = this.priority.getId();
        }
        if (this.status) {
            ticketString.statusId = this.status.getId();
        }
        delete ticketString.reporter;
        delete ticketString.assignee;
        delete ticketString.category;
        delete ticketString.priority;
        delete ticketString.status;
        ticketString = decamelizeKeys(ticketString, '-');
        return js2xmlparser.parse("ticket", ticketString);
    };
    /**
     * Gets Ticket id
     * @return number
     */
    Ticket.prototype.getId = function () {
        return this.id;
    };
    /**
     * Gets Ticket Project ID
     * @return number
     */
    Ticket.prototype.getProjectId = function () {
        return this.projectId;
    };
    /**
     * Gets Ticket summary
     * @return string
     */
    Ticket.prototype.getSummary = function () {
        return this.summary;
    };
    /**
     * Gets Ticket Reporter
     * @return null|User
     */
    Ticket.prototype.getReporter = function () {
        return this.reporter;
    };
    /**
     * Gets Ticket Assignee
     * @return null|User
     */
    Ticket.prototype.getAssignee = function () {
        return this.assignee;
    };
    /**
     * Gets Ticket category
     * @return null|Category
     */
    Ticket.prototype.getCategory = function () {
        return this.category;
    };
    /**
     * Gets Ticket priority
     * @return null|Priority\Priority
     */
    Ticket.prototype.getPriority = function () {
        return this.priority;
    };
    /**
     * Gets Ticket status
     * @return null|Status\Status
     */
    Ticket.prototype.getStatus = function () {
        return this.status;
    };
    /**
     * Gets Ticket type
     * @return null|Type\Type
     */
    Ticket.prototype.getType = function () {
        return this.type;
    };
    /**
     * Gets Ticket estimated time
     * @return null|int
     */
    Ticket.prototype.getEstimate = function () {
        return this.estimatedTime;
    };
    /**
     * Gets Ticket total time spent
     * @return int
     */
    Ticket.prototype.getTotalTimeSpent = function () {
        return this.totalTimeSpent;
    };
    /**
     * Gets Ticket updated date
     * @return \DateTime
     */
    Ticket.prototype.getUpdatedAt = function () {
        return this.updatedAt;
    };
    /**
     * Gets Ticket created date
     * @return \DateTime
     */
    Ticket.prototype.getCreatedAt = function () {
        return this.createdAt;
    };
    /**
     * Returns time session collection
     * @return TimeSession\Collection
     */
    Ticket.prototype.getTimeSessions = function () {
        return this.timeSessionCollection;
    };
    Ticket.prototype.addTimeSession = function (timeSession) {
        this.timeSessionCollection.addTimeSession(timeSession);
        return this;
    };
    return Ticket;
}());
exports.default = Ticket;
