"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var js2xmlparser = require("js2xmlparser");
var decamelizeKeys = require('decamelize-keys');
var TimeSession = /** @class */ (function () {
    /**
     * Constructor
     * @param int $id
     * @param Project\Project $project
     * @param string $summary
     * @param int $minutes
     * @param \DateTime $sessionDate
     * @param User\User $user
     * @param null|Ticket\Ticket $ticket
     * @param \DateTime $updatedAt
     * @param \DateTime $createdAt
     * @return void
     */
    function TimeSession(id, project, summary, minutes, sessionDate, updatedAt, createdAt, user, ticket) {
        if (user === void 0) { user = null; }
        if (ticket === void 0) { ticket = null; }
        this.id = id;
        this.project = project;
        this.summary = summary;
        this.minutes = minutes;
        this.sessionDate = sessionDate;
        this.user = user;
        this.ticket = ticket;
        this.updatedAt = updatedAt;
        this.createdAt = createdAt;
    }
    TimeSession.prototype.convertToXml = function () {
        var timeSession = JSON.stringify(this);
        var sessionString = JSON.parse(timeSession);
        sessionString.project = this.project.getId();
        sessionString.userId = null;
        if (this.user) {
            sessionString.userId = this.user.getId();
        }
        sessionString.ticketId = null;
        if (this.ticket) {
            sessionString.ticketId = this.ticket.getId();
        }
        delete sessionString.user;
        delete sessionString.ticket;
        sessionString = decamelizeKeys(sessionString, '-');
        return js2xmlparser.parse("time-session", sessionString);
    };
    /**
     * Gets Time Session id
     * @return int
     */
    TimeSession.prototype.getId = function () {
        return this.id;
    };
    /**
     * Gets Time Session Project
     * @return Project\Project
     */
    TimeSession.prototype.getProject = function () {
        return this.project;
    };
    /**
     * Gets Time Session summary
     * @return string
     */
    TimeSession.prototype.getSummary = function () {
        return this.summary;
    };
    /**
     * Gets Time Session minutes
     * @return int
     */
    TimeSession.prototype.getMinutes = function () {
        return this.minutes;
    };
    /**
     * Gets Time Session date
     * @return \DateTime
     */
    TimeSession.prototype.getSessionDate = function () {
        return this.sessionDate;
    };
    /**
     * Gets Time Session User
     * @return null|User\User
     */
    TimeSession.prototype.getUser = function () {
        return this.user;
    };
    /**
     * Gets Time Session Ticket
     * @return null|Ticket\Ticket
     */
    TimeSession.prototype.getTicket = function () {
        return this.ticket;
    };
    /**
     * Gets Time Session updated date
     * @return \DateTime
     */
    TimeSession.prototype.getUpdatedAt = function () {
        return this.updatedAt;
    };
    /**
     * Gets Time Session created date
     * @return \DateTime
     */
    TimeSession.prototype.getCreatedAt = function () {
        return this.createdAt;
    };
    return TimeSession;
}());
exports.default = TimeSession;
