import TimeSessionCollection from "../TimeSession/TimeSessionCollection";
import TimeSession from "../TimeSession/TimeSession";
import BaseModelInterface from "../BaseModelInterface";
export default class User implements BaseModelInterface {
    private id;
    private username;
    private company;
    private emailAddress;
    private firstName;
    private lastName;
    private gravatarUrl;
    private enabled;
    private timeSessionCollection;
    /**
     * Constructor
     * @param int $id
     * @param string $username
     * @param string $company
     * @param string $emailAddress
     * @param string $firstName
     * @param string $lastName
     * @param string $gravatarUrl
     * @param bool $enabled
     * @return void
     */
    constructor(id: number, enabled: boolean, username?: string | null, company?: string | null, emailAddress?: string | null, firstName?: string | null, lastName?: string | null, gravatarUrl?: string | null);
    convertToXml(): any;
    /**
     * Gets user id
     * @return int
     */
    getId(): number;
    /**
     * Gets username
     * @return null|string
     */
    getUsername(): string | null;
    /**
     * Gets company
     * @return null|string
     */
    getCompany(): string | null;
    /**
     * Gets email address
     * @return null|string
     */
    getEmailAddress(): string | null;
    /**
     * Gets first name
     * @return null|string
     */
    getFirstName(): string | null;
    /**
     * Gets last name
     * @return null|string
     */
    getLastName(): string | null;
    getFullName(): string;
    /**
     * Gets gravatar url
     * @return null|string
     */
    getGravatarUrl(): string | null;
    /**
     * Gets enabled
     * @return bool
     */
    getEnabled(): boolean;
    /**
     * Returns time session collection
     * @return TimeSession\Collection
     */
    getTimeSessions(): TimeSessionCollection;
    addTimeSession(timeSession: TimeSession): this;
}
