"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var TimeSessionCollection_1 = require("../TimeSession/TimeSessionCollection");
var js2xmlparser = require("js2xmlparser");
var decamelizeKeys = require('decamelize-keys');
var User = /** @class */ (function () {
    /**
     * Constructor
     * @param int $id
     * @param string $username
     * @param string $company
     * @param string $emailAddress
     * @param string $firstName
     * @param string $lastName
     * @param string $gravatarUrl
     * @param bool $enabled
     * @return void
     */
    function User(id, enabled, username, company, emailAddress, firstName, lastName, gravatarUrl) {
        if (username === void 0) { username = null; }
        if (company === void 0) { company = null; }
        if (emailAddress === void 0) { emailAddress = null; }
        if (firstName === void 0) { firstName = null; }
        if (lastName === void 0) { lastName = null; }
        if (gravatarUrl === void 0) { gravatarUrl = null; }
        this.id = id;
        this.username = username;
        this.company = company;
        this.emailAddress = emailAddress;
        this.firstName = firstName;
        this.lastName = lastName;
        this.gravatarUrl = gravatarUrl;
        this.enabled = enabled;
        this.timeSessionCollection = new TimeSessionCollection_1.default();
    }
    User.prototype.convertToXml = function () {
        var user = JSON.stringify(this);
        var userString = JSON.parse(user);
        delete userString.timeSessionCollection;
        userString = decamelizeKeys(userString, '-');
        return js2xmlparser.parse("user", userString);
    };
    /**
     * Gets user id
     * @return int
     */
    User.prototype.getId = function () {
        return this.id;
    };
    /**
     * Gets username
     * @return null|string
     */
    User.prototype.getUsername = function () {
        return this.username;
    };
    /**
     * Gets company
     * @return null|string
     */
    User.prototype.getCompany = function () {
        return this.company;
    };
    /**
     * Gets email address
     * @return null|string
     */
    User.prototype.getEmailAddress = function () {
        return this.emailAddress;
    };
    /**
     * Gets first name
     * @return null|string
     */
    User.prototype.getFirstName = function () {
        return this.firstName;
    };
    /**
     * Gets last name
     * @return null|string
     */
    User.prototype.getLastName = function () {
        return this.lastName;
    };
    User.prototype.getFullName = function () {
        return this.getFirstName() + " " + this.getLastName();
    };
    /**
     * Gets gravatar url
     * @return null|string
     */
    User.prototype.getGravatarUrl = function () {
        return this.gravatarUrl;
    };
    /**
     * Gets enabled
     * @return bool
     */
    User.prototype.getEnabled = function () {
        return this.enabled;
    };
    /**
     * Returns time session collection
     * @return TimeSession\Collection
     */
    User.prototype.getTimeSessions = function () {
        return this.timeSessionCollection;
    };
    User.prototype.addTimeSession = function (timeSession) {
        this.timeSessionCollection.addTimeSession(timeSession);
        return this;
    };
    return User;
}());
exports.default = User;
